@@ -16,6 +16,8 @@ import sys
 import struct
 import codecs
 import errno
+import decimal
+from io import BytesIO
 
 try:
     import mmap
@@ -33,14 +35,23 @@ from ._compat import chr_, PY2, iteritems, iterbytes, integer_types, xrange, \
     izip, text_type, reraise
 
 
+def intround(value):
+    """Given a float returns a rounded int. Should give the same result on
+    both Py2/3
+    """
+
+    return int(decimal.Decimal.from_float(
+        value).to_integral_value(decimal.ROUND_HALF_EVEN))
+
+
 def is_fileobj(fileobj):
     """Returns:
         bool: if an argument passed ot mutagen should be treated as a
             file object
     """
 
-    # open() only handles str/bytes, so we can be strict
-    return not isinstance(fileobj, (text_type, bytes))
+    return not (isinstance(fileobj, (text_type, bytes)) or
+                hasattr(fileobj, "__fspath__"))
 
 
 def verify_fileobj(fileobj, writable=False):
@@ -199,6 +210,10 @@ def _openfile(instance, filething, filename, fileobj, writable, create):
     if filething is not None:
         if is_fileobj(filething):
             fileobj = filething
+        elif hasattr(filething, "__fspath__"):
+            filename = filething.__fspath__()
+            if not isinstance(filename, (bytes, text_type)):
+                raise TypeError("expected __fspath__() to return a filename")
         else:
             filename = filething
 
@@ -214,10 +229,24 @@ def _openfile(instance, filething, filename, fileobj, writable, create):
         yield FileThing(fileobj, filename, filename or fileobj_name(fileobj))
     elif filename is not None:
         verify_filename(filename)
+
+        inmemory_fileobj = False
         try:
             fileobj = open(filename, "rb+" if writable else "rb")
         except IOError as e:
-            if create and e.errno == errno.ENOENT:
+            if writable and e.errno == errno.EOPNOTSUPP:
+                # Some file systems (gvfs over fuse) don't support opening
+                # files read/write. To make things still work read the whole
+                # file into an in-memory file like object and write it back
+                # later.
+                # https://github.com/quodlibet/mutagen/issues/300
+                try:
+                    with open(filename, "rb") as fileobj:
+                        fileobj = BytesIO(fileobj.read())
+                except IOError as e2:
+                    raise MutagenError(e2)
+                inmemory_fileobj = True
+            elif create and e.errno == errno.ENOENT:
                 assert writable
                 try:
                     fileobj = open(filename, "wb+")
@@ -228,6 +257,15 @@ def _openfile(instance, filething, filename, fileobj, writable, create):
 
         with fileobj as fileobj:
             yield FileThing(fileobj, filename, filename)
+
+            if inmemory_fileobj:
+                assert writable
+                data = fileobj.getvalue()
+                try:
+                    with open(filename, "wb") as fileobj:
+                        fileobj.write(data)
+                except IOError as e:
+                    raise MutagenError(e)
     else:
         raise TypeError("Missing filename or fileobj argument")
 
@@ -318,8 +356,16 @@ def enum(cls):
             return "<%s.%s: %d>" % (type(self).__name__, map_[self], int(self))
         return "%d" % int(self)
 
+    def getstate(self):
+        return {}
+
+    def setstate(self, state):
+        assert not state
+
     setattr(new_type, "__repr__", repr_)
     setattr(new_type, "__str__", str_)
+    setattr(new_type, "__getstate__", getstate)
+    setattr(new_type, "__setstate__", setstate)
 
     return new_type
 
@@ -598,7 +644,7 @@ def get_size(fileobj):
 
 
 def read_full(fileobj, size):
-    """Like fileobj.read but raises IOError if no all requested data is
+    """Like fileobj.read but raises IOError if not all requested data is
     returned.
 
     If you want to distinguish IOError and the EOS case, better handle
