@@ -3,21 +3,31 @@
 from mutagen._util import DictMixin, cdata, insert_bytes, delete_bytes, \
     decode_terminated, dict_match, enum, get_size, BitReader, BitReaderError, \
     resize_bytes, seek_end, mmap_move, verify_fileobj, fileobj_name, \
-    read_full, flags, resize_file, fallback_move, encode_endian
+    read_full, flags, resize_file, fallback_move, encode_endian, loadfile, \
+    intround, verify_filename
 from mutagen._compat import text_type, itervalues, iterkeys, iteritems, PY2, \
-    cBytesIO, xrange, BytesIO
+    cBytesIO, xrange, BytesIO, builtins
 from tests import TestCase, get_temp_empty
 import os
 import random
 import tempfile
 import mmap
 import errno
+import pickle
 
 try:
     import fcntl
 except ImportError:
     fcntl = None
 
+import pytest
+
+
+def test_intround():
+    assert intround(2.5) == 2
+    assert intround(2.6) == 3
+    assert intround(2.4) == 2
+
 
 class FDict(DictMixin):
 
@@ -630,6 +640,12 @@ class Tdict_match(TestCase):
         self.assertEqual(dict_match({"[ab]": 1}, "[ab]"), None)
 
 
+@enum
+class ModuleFoo(object):
+    FOO = 1
+    BAR = 3
+
+
 class Tenum(TestCase):
 
     def test_enum(self):
@@ -651,6 +667,10 @@ class Tenum(TestCase):
         self.assertTrue(isinstance(str(Foo.FOO), str))
         self.assertTrue(isinstance(repr(Foo.FOO), str))
 
+    def test_enum_pickle(self):
+        assert pickle.loads(pickle.dumps(ModuleFoo.FOO)) == ModuleFoo.FOO
+        assert pickle.loads(pickle.dumps(ModuleFoo(0))) == ModuleFoo(0)
+
 
 class Tflags(TestCase):
 
@@ -732,6 +752,85 @@ class Tseek_end(TestCase):
             self.assertEqual(f.tell(), 0)
 
 
+class Tloadfile(TestCase):
+
+    def test_handle_readwrite_notsup(self):
+
+        @loadfile(method=False, writable=True)
+        def file_func(filething):
+            fileobj = filething.fileobj
+            assert fileobj.read(3) == b"foo"
+            fileobj.seek(0, 2)
+            fileobj.write(b"bar")
+
+        # first a normal test
+        filename = get_temp_empty()
+        try:
+            with open(filename, "wb") as h:
+                h.write(b"foo")
+            file_func(filename)
+            with open(filename, "rb") as h:
+                assert h.read() == b"foobar"
+        finally:
+            os.unlink(filename)
+
+        # now we mock open to return raise EOPNOTSUPP in case of mixed mode.
+        # things should still work since we edit the file in memory
+        raised = []
+        old_open = open
+
+        def mock_open(name, mode, *args):
+            if "+" in mode:
+                raised.append(True)
+                raise IOError(errno.EOPNOTSUPP, "nope")
+            return old_open(name, mode, *args)
+
+        builtins.open = mock_open
+        try:
+            filename = get_temp_empty()
+            try:
+                with open(filename, "wb") as h:
+                    h.write(b"foo")
+                file_func(filename)
+                with open(filename, "rb") as h:
+                    assert h.read() == b"foobar"
+            finally:
+                os.unlink(filename)
+        finally:
+            builtins.open = old_open
+
+        assert raised
+
+    def test_filename_from_fspath(self):
+
+        class FilePath(object):
+            def __init__(self, filename):
+                self.filename = filename
+
+            def __fspath__(self):
+                return self.filename
+
+        @loadfile(method=False, writable=True)
+        def file_func(filething):
+            fileobj = filething.fileobj
+            assert fileobj.read(3) == b"foo"
+            fileobj.seek(0, 2)
+            fileobj.write(b"bar")
+
+        filename = get_temp_empty()
+        try:
+            with open(filename, "wb") as h:
+                h.write(b"foo")
+            file_func(FilePath(filename))
+            with open(filename, "rb") as h:
+                assert h.read() == b"foobar"
+        finally:
+            os.unlink(filename)
+
+        with pytest.raises(TypeError, match=r'.*__fspath__.*'):
+            file_func(FilePath(42))
+
+
 class Tread_full(TestCase):
 
     def test_read_full(self):
@@ -909,3 +1008,22 @@ class TBitReader(TestCase):
         self.assertFalse(r.is_aligned())
         r.bits(1)
         self.assertTrue(r.is_aligned())
+
+
+class Tverify_filename(TestCase):
+
+    def test_verify_filename_fail(self):
+        self.assertRaises(ValueError, verify_filename, object())
+
+    def test_verify_filename(self):
+
+        class FilePath(object):
+            def __init__(self, filename):
+                self.filename = filename
+
+            def __fspath__(self):
+                return self.filename
+
+        verify_filename(FilePath("foo"))
+        verify_filename("foo")
+        verify_filename(b"foo")
